@@ -179,7 +179,7 @@ class CsvsConverter(object):
                     'tenant_ref': self.tenant_ref,
                     'cloud_ref': self.cloud_ref,
                     'type': 'VS_TYPE_NORMAL',
-                    'enabled': True,
+                    'enabled': enabled,
                     'traffic_enabled': enabled,
                     'services': []
                 }
@@ -187,7 +187,7 @@ class CsvsConverter(object):
                     vrf_ref = ns_util.get_object_ref(vrf, 'vrfcontext',
                                                      tenant=self.tenant_name,
                                                      cloud_name=self.cloud_name)
-                    vs_obj['vrf_ref'] = vrf_ref
+                    vs_obj['vrf_context_ref'] = vrf_ref
                 if se_group:
                     se_group_ref = ns_util.get_object_ref(se_group,
                                                     'serviceenginegroup',
@@ -381,9 +381,10 @@ class CsvsConverter(object):
                                 vs_obj[avi_ssl_ref] = [updated_ssl_ref]
                             elif [obj for obj in avi_config[
                                   'SSLKeyAndCertificate'] if obj['name'] ==
-                                  ckname + '-dummy']:
+                                  '%s-%s' % (ckname, ns_constants.PLACE_HOLDER_STR)]:
                                 updated_ssl_ref = \
-                                    ns_util.get_object_ref(ckname + '-dummy',
+                                    ns_util.get_object_ref('%s-%s' % (
+                                        ckname, ns_constants.PLACE_HOLDER_STR),
                                         OBJECT_TYPE_SSL_KEY_AND_CERTIFICATE,
                                         self.tenant_name)
                                 vs_obj[avi_ssl_ref] = [updated_ssl_ref]
@@ -565,7 +566,7 @@ class CsvsConverter(object):
                 is_shared = ns_util.is_shared_same_vip(
                     vs_obj, cs_vs_list, avi_config, self.tenant_name,
                     self.cloud_name, self.tenant_ref, self.cloud_ref,
-                    self.controller_version, self.prefix)
+                    self.controller_version, self.prefix, input_vrf=vrf)
                 if is_shared:
                     skipped_status = 'Skipped: %s Same vip shared by another ' \
                                      'virtual service' % vs_name
