@@ -195,7 +195,7 @@ class LbvsConverter(object):
                     'type': 'VS_TYPE_NORMAL',
                     'tenant_ref': self.tenant_ref,
                     'cloud_ref': self.cloud_ref,
-                    'enabled': True,
+                    'enabled': enabled,
                     'traffic_enabled': enabled,
                     'services': [],
                 }
@@ -204,7 +204,7 @@ class LbvsConverter(object):
                     vrf_ref = ns_util.get_object_ref(
                         vrf, 'vrfcontext', tenant=self.tenant_name,
                         cloud_name=self.cloud_name)
-                    vs_obj['vrf_ref'] = vrf_ref
+                    vs_obj['vrf_context_ref'] = vrf_ref
                 if segroup:
                     se_group_ref = ns_util.get_object_ref(
                         segroup, 'serviceenginegroup', tenant=self.tenant_name,
@@ -568,7 +568,8 @@ class LbvsConverter(object):
                     is_shared = ns_util.is_shared_same_vip(
                         vs_obj, avi_config['VirtualService'], avi_config,
                         self.tenant_name, self.cloud_name, self.tenant_ref,
-                        self.cloud_ref, self.controller_version, self.prefix)
+                        self.cloud_ref, self.controller_version, self.prefix,
+                        input_vrf=vrf)
                     if is_shared:
                         skipped_status = 'Skipped: %s Same vip shared by ' \
                                          'another virtual service' % vs_name
@@ -625,9 +626,10 @@ class LbvsConverter(object):
                                 vs_obj[avi_ssl_ref] = [updated_ssl_ref]
                             elif [obj for obj in
                                   avi_config['SSLKeyAndCertificate']
-                                  if obj['name'] == ckname + '-dummy']:
-                                updated_ssl_ref = ns_util.get_object_ref(
-                                    ckname + '-dummy',
+                                  if obj['name'] == '%s-%s' % (
+                                        ckname, ns_constants.PLACE_HOLDER_STR)]:
+                                updated_ssl_ref = ns_util.get_object_ref('%s-%s' % (
+                                        ckname, ns_constants.PLACE_HOLDER_STR),
                                     OBJECT_TYPE_SSL_KEY_AND_CERTIFICATE,
                                     self.tenant_name)
                                 vs_obj[avi_ssl_ref] = [updated_ssl_ref]
