@@ -1,6 +1,8 @@
 import os
 import re
 import logging
+from functools import reduce
+
 import avi.migrationtools.netscaler_converter.ns_constants as ns_constants
 import math
 from avi.migrationtools.netscaler_converter.ns_constants \
@@ -75,7 +77,7 @@ class MonitorConverter(object):
         ns_monitors = ns_config.get('add lb monitor', {})
         total_size = len(ns_monitors.keys())
         count = 0
-        print "Converting Monitors..."
+        print("Converting Monitors...")
         self.add_ns_default_monitors(avi_config)
         for name in ns_monitors.keys():
             count = count + 1
@@ -94,14 +96,15 @@ class MonitorConverter(object):
                                                prefix='Progress', suffix='')
                     continue
 
-                avi_monitor['name'] = '%s-%s' % (avi_monitor['name'], 'dummy')
+                avi_monitor['name'] = '%s-%s' % (
+                    avi_monitor['name'], ns_constants.PLACE_HOLDER_STR)
                 avi_monitor["type"] = "HEALTH_MONITOR_EXTERNAL"
                 ext_monitor = {
                     "command_code": ""
                 }
                 avi_monitor["external_monitor"] = ext_monitor
                 avi_config['HealthMonitor'].append(avi_monitor)
-                msg = ('Monitor type %s not supported created dummy '
+                msg = ('Monitor type %s not supported created placeholder object '
                             'external monitor:%s' %
                             (ns_monitor_type, name))
                 LOG.warning(msg)
