@@ -361,7 +361,7 @@ class ServiceConverter(object):
         # Get the total size of object
         self.total_size = self.total_size + len(ns_services) + \
                           len(ns_service_groups)
-        print "Converting Pools..."
+        print("Converting Pools...")
         for key in ns_services:
             try:
                 # Added count to increment progress.
@@ -443,9 +443,9 @@ class ServiceConverter(object):
                                     ssl_key_cert_ref
                             elif [key_cert for key_cert in avi_config[
                                 'SSLKeyAndCertificate'] if key_cert[
-                                'name'] == certname + '-dummy']:
+                                'name'] == '%s-%s' % (certname, ns_constants.PLACE_HOLDER_STR)]:
                                 ssl_key_cert_ref = ns_util.get_object_ref(
-                                            certname + '-dummy',
+                                            '%s-%s' % (certname, ns_constants.PLACE_HOLDER_STR),
                                             OBJECT_TYPE_SSL_KEY_AND_CERTIFICATE,
                                             self.tenant_name)
                                 pool_obj['ssl_key_and_certificate_ref'] = \
@@ -556,6 +556,12 @@ class ServiceConverter(object):
                     'cloud_ref': self.cloud_ref
                 }
 
+                if vrf:
+                    vrf_ref = ns_util.get_object_ref(
+                        vrf, 'vrfcontext', tenant=self.tenant_name,
+                        cloud_name=self.cloud_name)
+                    pool_obj['vrf_ref'] = vrf_ref
+
                 # Added code to disable translation port
                 if use_service_port:
                     pool_obj['use_service_port'] = use_service_port
@@ -604,9 +610,10 @@ class ServiceConverter(object):
                                     ssl_key_cert_ref
                             elif [key_cert for key_cert in avi_config[
                                 'SSLKeyAndCertificate'] if key_cert[
-                                      'name'] == certname + '-dummy']:
+                                      'name'] == '%s-%s' % (
+                                    certname, ns_constants.PLACE_HOLDER_STR)]:
                                 ssl_key_cert_ref = ns_util.get_object_ref(
-                                    certname + '-dummy',
+                                    '%s-%s' % (certname, ns_constants.PLACE_HOLDER_STR),
                                     OBJECT_TYPE_SSL_KEY_AND_CERTIFICATE,
                                     self.tenant_name)
                                 pool_obj['ssl_key_and_certificate_ref'] = \
@@ -715,7 +722,8 @@ class ServiceConverter(object):
                                + avi_config['HealthMonitor']) if monitor[
                                'name'] == monitor_name]
                     if not monitor:
-                        monitor_name = '%s-%s' % (monitor_name, 'dummy')
+                        monitor_name = '%s-%s' % (
+                            monitor_name, ns_constants.PLACE_HOLDER_STR)
                         monitor = [monitor for monitor in
                                    avi_config['HealthMonitor']
                                    if monitor['name'] == monitor_name]
@@ -857,7 +865,8 @@ class ServiceConverter(object):
                           avi_config['HealthMonitor']) if monitor['name'] ==
                            monitor_name]
                 if not monitor:
-                    monitor_name = '%s-%s' % (monitor_name, 'dummy')
+                    monitor_name = '%s-%s' % (
+                        monitor_name, ns_constants.PLACE_HOLDER_STR)
                     monitor = [monitor for monitor in
                                avi_config['HealthMonitor']
                                if monitor['name'] == monitor_name]
