@@ -20,7 +20,8 @@ setup(
              'avi/migrationtools/gss_convertor/gss_convertor.py',
              'avi/migrationtools/ace_converter/ace_converter.py',
              'avi/migrationtools/config_patch.py',
-             'avi/migrationtools/ansible/avi_config_to_ansible.py'],
+             'avi/migrationtools/ansible/avi_config_to_ansible.py',
+             'avi/migrationtools/f5_discovery.py'],
     classifiers=[
         'Operating System :: OS Independent',
         'Programming Language :: Python',
@@ -33,7 +34,7 @@ setup(
                       'pycrypto', 'ecdsa', 'pyOpenssl', 'nose-html-reporting',
                       'nose-testconfig', 'ConfigParser', 'xlsxwriter', 'jinja2',
                       'pandas', 'openpyxl', 'appdirs',  'pexpect',
-                      'unittest2', 'networkx'],
+                      'unittest2', 'networkx', 'xmltodict'],
     package_data={'avi': ['*.cfg', '*.conf', '*.crt', '*.crl', '*.json',
                           '*.jinja', '*.key', '*.pem', '*.xml',
                           '*.yaml', '*.yml'],
