@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 import argparse
 import json
 import os
@@ -23,7 +23,11 @@ def filter_for_vs(avi_config, vs_names):
     """
     new_config = dict()
     new_config['VirtualService'] = []
-    virtual_services = vs_names.split(',')
+    virtual_services = []
+    if vs_names and type(vs_names) == str:
+        virtual_services = vs_names.split(',')
+    elif vs_names and type(vs_names) == list:
+        virtual_services = vs_names
 
     for vs_name in virtual_services:
         vs = [vs for vs in avi_config['VirtualService']
@@ -58,7 +62,7 @@ def search_obj(entity, name, new_config, avi_config, depth):
     found_obj = [obj for obj in found_obj_list if obj['name'] == name]
     if found_obj:
         found_obj = found_obj[0]
-        print (' | '*depth), '|- %s(%s)' % (name, path_key_map[entity])
+        print(' | '*depth + '|- %s(%s)' % (name, path_key_map[entity]))
     elif entity in ['applicationprofile', 'networkprofile', 'healthmonitor',
                     'sslkeyandcertificate', 'sslprofile']:
         if str.startswith(str(name), 'System-'):
